==> openliberty-src-20.0.0.3.zip: open-liberty-gm-20.0.0.3/dev/com.ibm.ws.security.fat.common.jwt/src/com/ibm/ws/security/fat/common/jwt/JwtMessageConstants.java <==
/*******************************************************************************
 * Copyright (c) 2018, 2019 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 * IBM Corporation - initial API and implementation
 *******************************************************************************/
package com.ibm.ws.security.fat.common.jwt;

public class JwtMessageConstants extends com.ibm.ws.security.fat.common.MessageConstants {

    public static final String CWWKS6005E_CONFIG_NOT_AVAILABLE = "CWWKS6005E";

    public static final String CWWKS6007E_BAD_KEY_ALIAS = "CWWKS6007E";
    public static final String CWWKS6008E_BUILD_ID_UNKNOWN = "CWWKS6008E";
    public static final String CWWKS6009E_INVALID_CLAIM = "CWWKS6009E";

    public static final String CWWKS6015E_INVALID_CLAIM = "CWWKS6015E";
    public static final String CWWKS6016E_BAD_KEY_ALIAS = "CWWKS6016E";
    public static final String CWWKS6017E_BAD_EMPTY_TOKEN = "CWWKS6017E";
    public static final String CWWKS6018E_CLAIM_MUST_BE_GT_ZERO = "CWWKS6018E";
    public static final String CWWKS6019E_BAD_DATA_TYPE = "CWWKS6019E";
    public static final String CWWKS6020E_CAN_NOT_CAST = "CWWKS6020E";
    public static final String CWWKS6021E_CLAIMS_ARE_NOT_VALID = "CWWKS6021E";
    public static final String CWWKS6022E_ISSUER_NOT_TRUSTED = "CWWKS6022E";
    public static final String CWWKS6023E_BAD_AUDIENCE = "CWWKS6023E";
    public static final String CWWKS6024E_IAT_AFTER_EXP = "CWWKS6024E";
    public static final String CWWKS6025E_TOKEN_EXPIRED = "CWWKS6025E";
    public static final String CWWKS6026E_FUTURE_NBF = "CWWKS6026E";

    public static final String CWWKS6028E_BAD_ALGORITHM = "CWWKS6028E";
    public static final String CWWKS6029E_NO_SIGNING_KEY = "CWWKS6029E";
    public static final String CWWKS6030E_JWT_CONSUMER_ID_DOESNT_EXIST = "CWWKS6030E";
    public static final String CWWKS6031E_JWT_CONSUMER_CANNOT_PROCESS_STRING = "CWWKS6031E";
    public static final String CWWKS6032E_JWT_CONSUMER_SHARED_KEY_NOT_RETRIEVED = "CWWKS6032E";
    public static final String CWWKS6033E_JWT_CONSUMER_PUBLIC_KEY_NOT_RETRIEVED = "CWWKS6033E";
    public static final String CWWKS6034E_JWT_CONSUMER_SHARED_KEY_NOT_FOUND = "CWWKS6034E";

    public static final String CWWKS6036E_INVALID_KEY = "CWWKS6036E";
    public static final String CWWKS6037E_INVALID_SIG_ALG = "CWWKS6037E";

    public static final String CWWKS6039E_JWK_BAD_SIG_ALG = "CWWKS6039E";
    public static final String CWWKS6040E_JWT_STRING_EMPTY = "CWWKS6040E";
    public static final String CWWKS6041E_JWT_SIGNATURE_INVALID = "CWWKS6041E";
    public static final String CWWKS6042E_BAD_EXP_TIME = "CWWKS6042E";

    public static final String CWWKS6043E_MALFORMED_CLAIM = "CWWKS6043E";
    public static final String CWWKS6044E_IAT_AFTER_CURRENT_TIME = "CWWKS6044E";
    public static final String CWWKS6045E_JTI_REUSED = "CWWKS6045E";

    public static final String CWWKS6047E_MULTIKEY_NO_ALIAS = "CWWKS6047E";

    public static final String CWWKS6052E_JWT_TRUSTED_ISSUERS_NULL = "CWWKS6052E";

}

==> openliberty-src-20.0.0.11.zip: open-liberty-gm-20.0.0.11/dev/com.ibm.ws.security.fat.common.jwt/src/com/ibm/ws/security/fat/common/jwt/JwtMessageConstants.java <==
/*******************************************************************************
 * Copyright (c) 2018, 2020 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 * IBM Corporation - initial API and implementation
 *******************************************************************************/
package com.ibm.ws.security.fat.common.jwt;

public class JwtMessageConstants extends com.ibm.ws.security.fat.common.MessageConstants {

    public static final String CWWKS6005E_CONFIG_NOT_AVAILABLE = "CWWKS6005E";

    public static final String CWWKS6007E_BAD_KEY_ALIAS = "CWWKS6007E";
    public static final String CWWKS6008E_BUILD_ID_UNKNOWN = "CWWKS6008E";
    public static final String CWWKS6009E_INVALID_CLAIM = "CWWKS6009E";

    public static final String CWWKS6015E_INVALID_CLAIM = "CWWKS6015E";
    public static final String CWWKS6016E_BAD_KEY_ALIAS = "CWWKS6016E";
    public static final String CWWKS6017E_BAD_EMPTY_TOKEN = "CWWKS6017E";
    public static final String CWWKS6018E_CLAIM_MUST_BE_GT_ZERO = "CWWKS6018E";
    public static final String CWWKS6019E_BAD_DATA_TYPE = "CWWKS6019E";
    public static final String CWWKS6020E_CAN_NOT_CAST = "CWWKS6020E";
    public static final String CWWKS6021E_CLAIMS_ARE_NOT_VALID = "CWWKS6021E";
    public static final String CWWKS6022E_ISSUER_NOT_TRUSTED = "CWWKS6022E";
    public static final String CWWKS6023E_BAD_AUDIENCE = "CWWKS6023E";
    public static final String CWWKS6024E_IAT_AFTER_EXP = "CWWKS6024E";
    public static final String CWWKS6025E_TOKEN_EXPIRED = "CWWKS6025E";
    public static final String CWWKS6026E_FUTURE_NBF = "CWWKS6026E";

    public static final String CWWKS6028E_BAD_ALGORITHM = "CWWKS6028E";
    public static final String CWWKS6029E_NO_SIGNING_KEY = "CWWKS6029E";
    public static final String CWWKS6030E_JWT_CONSUMER_ID_DOESNT_EXIST = "CWWKS6030E";
    public static final String CWWKS6031E_JWT_CONSUMER_CANNOT_PROCESS_STRING = "CWWKS6031E";
    public static final String CWWKS6032E_JWT_CONSUMER_SHARED_KEY_NOT_RETRIEVED = "CWWKS6032E";
    public static final String CWWKS6033E_JWT_CONSUMER_PUBLIC_KEY_NOT_RETRIEVED = "CWWKS6033E";
    public static final String CWWKS6034E_JWT_CONSUMER_SHARED_KEY_NOT_FOUND = "CWWKS6034E";

    public static final String CWWKS6036E_INVALID_KEY = "CWWKS6036E";
    public static final String CWWKS6037E_INVALID_SIG_ALG = "CWWKS6037E";

    public static final String CWWKS6039E_JWK_BAD_SIG_ALG = "CWWKS6039E";
    public static final String CWWKS6040E_JWT_STRING_EMPTY = "CWWKS6040E";
    public static final String CWWKS6041E_JWT_SIGNATURE_INVALID = "CWWKS6041E";
    public static final String CWWKS6042E_BAD_EXP_TIME = "CWWKS6042E";

    public static final String CWWKS6043E_MALFORMED_CLAIM = "CWWKS6043E";
    public static final String CWWKS6044E_IAT_AFTER_CURRENT_TIME = "CWWKS6044E";
    public static final String CWWKS6045E_JTI_REUSED = "CWWKS6045E";

    public static final String CWWKS6047E_MULTIKEY_NO_ALIAS = "CWWKS6047E";

    public static final String CWWKS6052E_JWT_TRUSTED_ISSUERS_NULL = "CWWKS6052E";
    public static final String CWWKS6054E_INVALID_AMR_CLAIM = "CWWKS6054E";
    public static final String CWWKS6055W_BETA_SIGNATURE_ALGORITHM_USED = "CWWKS6055W";

    public static final String CWPKI0812E_CANT_FIND_KEY = "CWPKI0812E";

}
